pub enum PlaybackState {
Paused {
position: f64,
},
Pausing {
position: f64,
},
Playing {
position: f64,
},
Queued,
Stopped,
Stopping {
position: f64,
},
WaitingToResume {
position: f64,
},
Resuming {
position: f64,
},
}Expand description
Playback status of a currently playing sound.
Variants
Paused
The instance is paused.
Pausing
The instance is fading out and will be paused when the fadeout is finished.
Playing
The instance is playing.
Queued
The instance is queued
Stopped
The instance cannot be found anymore. This might might mean it was playing before and is stopped now, or it never played in the channel were you asked for it.
Stopping
The instance is fading out and will be stopped when the fadeout is finished.
WaitingToResume
The sound is paused, but is schedule to resume in the future.
Resuming
The sound is fading back in after being previously paused.
Implementations